### Phrase Translator

A very simple package to translate single words and phrases between different languages.

[![PyPI Version][pypi-image]][pypi-url]
[![Build Status][build-image]][build-url]
[![Versions][versions-image]][versions-url]

...

<!-- Badges: -->

[pypi-image]: https://img.shields.io/pypi/v/phrase-translator
[pypi-url]: https://pypi.org/project/phrase-translator/
[build-image]: https://github.com/fr2501/phrase-translator/actions/workflows/build.yaml/badge.svg
[build-url]: https://github.com/fr2501/phrase-translator/actions/workflows/build.yaml
[versions-image]: https://img.shields.io/pypi/pyversions/phrase-translator/
[versions-url]: https://pypi.org/project/phrase-translator/
